==> 0.0.1.tar.gz: lib/services/systemMessage.dart <==
import 'package:origami_database/models/databaseRoute.dart';
import 'package:origami_database/models/queryModel.dart';
import 'package:origami_database/models/sortModel.dart';
import 'package:origami_messaging/models/dbModels/systemMessageAccounts.dart';
import 'package:origami_messaging/models/dbModels/systemMessageModel.dart';
import 'package:origami_messaging/models/messagingConfig.dart';
import 'package:origami_messaging/models/messagingDbTables.dart';
import 'package:origamicore/models/externalService.dart';
import 'package:origamicore/models/messageModel.dart';
import 'package:origamicore/routing/routeResponse.dart';

class SystemMessage
{
  static String context; 
  static void attachService(Map<String, ExtrnalService> data, MessagingConfig config)
  {  
    context=config.dbContext;  
    data['getSystemMessages']=ExtrnalService(function:getSystemMessages,isPublic: false,requireProp: ['userid'] ); 
    data['isNewMessage']=ExtrnalService(function:isNewMessage,isPublic: false,requireProp: ['userid'] ); 
  }  
  
  static Future<RouteResponse> isNewMessage(MessageModel message) async
  { 
    var userid=message.session['data']['userid'];
    var messages=await DatabaseRoute<SystemMessageModel>().searchOne(context, MessagingDbTables.systemMessage, QueryModel(
      sort: [SortModel(isDesc: true,prop:'time')]
    ));
    var isNew=true;
    if(messages!=null)
    {
      var user=await DatabaseRoute<SystemMessageAccount>().searchOne(context, MessagingDbTables.systemMessageAccount, QueryModel(
        where: {'_id':userid}
      ));
      if(user!=null && user.viewTime>=messages.time)
      {
        isNew=false;
      }
    } 
    return RouteResponse(response: ResponseDataModel(data: isNew,isDone: true));
  }
  static Future<RouteResponse> getSystemMessages(MessageModel message) async
  { 
    var userid=message.session['data']['userid'];
    var messages=await DatabaseRoute<SystemMessageModel>().search(context, MessagingDbTables.systemMessage, QueryModel(
      sort: [SortModel(isDesc: true,prop:'time')]
    ));
    await DatabaseRoute<SystemMessageAccount>().save(context, MessagingDbTables.systemMessageAccount,[],
    SystemMessageAccount(id:userid,viewTime: DateTime.now().millisecondsSinceEpoch ).toJson());
    return RouteResponse(response: ResponseDataModel(data: messages.map((e) => e.toJson()).toList(),isDone: true));
  }
}

==> 0.0.3.tar.gz: lib/services/systemMessage.dart <==
import 'package:origami_database/models/databaseRoute.dart';
import 'package:origami_database/models/queryModel.dart';
import 'package:origami_database/models/sortModel.dart';
import 'package:origami_messaging/models/dbModels/systemMessageAccounts.dart';
import 'package:origami_messaging/models/dbModels/systemMessageModel.dart';
import 'package:origami_messaging/models/messagingConfig.dart';
import 'package:origami_messaging/models/messagingDbTables.dart';
import 'package:origamicore/models/externalService.dart';
import 'package:origamicore/models/messageModel.dart';
import 'package:origamicore/routing/routeResponse.dart';

class SystemMessage
{
  static String context; 
  static void attachService(Map<String, ExtrnalService> data, MessagingConfig config)
  {  
    context=config.dbContext;  
    data['getSystemMessages']=ExtrnalService(function:getSystemMessages,isPublic: false,requireProp: ['userid'] ); 
    data['isNewMessage']=ExtrnalService(function:isNewMessage,isPublic: false,requireProp: ['userid'] ); 
  }  
  
  static Future<RouteResponse> isNewMessage(MessageModel message) async
  { 
    var userid=message.session['data']['userid'].toString();
    var messages=await DatabaseRoute<SystemMessageModel>().searchOne(context, MessagingDbTables.systemMessage, QueryModel(
      sort: [SortModel(isDesc: true,prop:'time')]
    ));
    var isNew=true;
    if(messages!=null)
    {
      var user=await DatabaseRoute<SystemMessageAccount>().searchOne(context, MessagingDbTables.systemMessageAccount, QueryModel(
        where: {'_id':userid}
      ));
      if(user!=null && user.viewTime>=messages.time)
      {
        isNew=false;
      }
    } 
    return RouteResponse(response: ResponseDataModel(data: isNew,isDone: true));
  }
  static Future<RouteResponse> getSystemMessages(MessageModel message) async
  { 
    var userid=message.session['data']['userid'].toString();
    var messages=await DatabaseRoute<SystemMessageModel>().search(context, MessagingDbTables.systemMessage, QueryModel(
      sort: [SortModel(isDesc: true,prop:'time')]
    ));
    await DatabaseRoute<SystemMessageAccount>().save(context, MessagingDbTables.systemMessageAccount,[],
    SystemMessageAccount(id:userid,viewTime: DateTime.now().millisecondsSinceEpoch ).toJson());
    return RouteResponse(response: ResponseDataModel(data: messages.map((e) => e.toJson()).toList(),isDone: true));
  }
}
